/**
 * Conversation widget
 *
 * Allows to display all the components
 * of a single conversation
 *
 * @author Pierre HUBERT
 */
#ifndef CONVERSATIONWIDGET_H
#define CONVERSATIONWIDGET_H

#include <QWidget>

#include "../data/conversation.h"
#include "../data/userslist.h"
#include "../data/conversationmessage.h"
#include "../data/conversationmessageslist.h"

namespace Ui {
class ConversationWidget;
}

class ConversationHelper;

class ConversationWidget : public QWidget
{
    Q_OBJECT

public:
    explicit ConversationWidget(const Conversation &conversation, const UsersList &list, QWidget *parent = nullptr);
    ~ConversationWidget();

public slots:

    /**
     * Send the message entered by the user in the form
     */
    void sendMessage();



private slots:

    /**
     * This slot is called at regular interval in order to
     * update regulary the list of messages
     */
    void refreshTimeout();

    /**
     * Method called once we have got the list of messages
     *
     * @param success TRUE in case of success of the operation / FALSE else
     * @param list The list of downloaded messages
     */
    void getMessagesCallback(bool success, QList<ConversationMessage> list);

    /**
     * Method called once the server replied to a send conversation
     * message request
     *
     * @param success TRUE in case of success / FALSE else
     */
    void sendMessageCallback(bool success);

    void on_sendMessageButton_clicked();

    void on_messageContentInput_returnPressed();

private:

    /**
     * Methods to get and set send message form
     * lock state
     */
    void setSendMessageFormLocked(bool lock);
    bool isSendMessageFormLocked();
    void resetSendMessageForm();

    //Private fields
    Ui::ConversationWidget *ui;
    QTimer *mTimer;
    ConversationHelper *mConversationHelper;
    Conversation mConversation;
    UsersList mUsersList;
    ConversationMessagesList mMessages;
};

#endif // CONVERSATIONWIDGET_H
